Package org.quartzplus
Interface OnErrorRepeatable
public interface OnErrorRepeatable
Interface to specify repeatable settings for erroneous job execution.
Can be used with simple or cron triggers
-
Method Summary
Modifier and TypeMethodDescriptionintSpecifies repeat count of job bean executeJob(...) method in case of exception inside executeJob(...)intSpecifies delay in milliseconds between erroneous executions of job bean executeJob(...)
-
Method Details
-
getOnErrorRepeatCount
int getOnErrorRepeatCount()Specifies repeat count of job bean executeJob(...) method in case of exception inside executeJob(...) -
getOnErrorRepeatDelay
int getOnErrorRepeatDelay()Specifies delay in milliseconds between erroneous executions of job bean executeJob(...)
-