Class JobServiceException

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.quartzplus.exception.JobServiceException
All Implemented Interfaces:
Serializable

public class JobServiceException extends Exception
Exception thrown by the job service when an error occurs during job management or execution.

This class acts as a high-level wrapper for various underlying issues encountered while interacting with the Quartz scheduler or processing job-related logic.

See Also:
  • Constructor Details

    • JobServiceException

      public JobServiceException(String message)