Class JobTriggerIncorrectState

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.quartzplus.exception.JobTriggerIncorrectState
All Implemented Interfaces:
Serializable

@ResponseStatus(value=BAD_REQUEST, reason="Job/trigger state is incorrect") public class JobTriggerIncorrectState extends Exception
Exception thrown when an operation is requested on a Job or Trigger that is in an invalid state for that action (e.g., attempting to pause an already paused trigger).

When thrown within the SchedulerRestController, it results in an HTTP 400 Bad Request response to the client.

See Also:
  • Constructor Details

    • JobTriggerIncorrectState

      public JobTriggerIncorrectState()